#[non_exhaustive]pub enum BreakPoint {
AtPosition {
source: Option<ImmutableString>,
pos: Position,
enabled: bool,
},
AtFunctionName {
name: ImmutableString,
enabled: bool,
},
AtFunctionCall {
name: ImmutableString,
args: usize,
enabled: bool,
},
AtProperty {
name: ImmutableString,
enabled: bool,
},
}Expand description
A break-point for debugging.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
AtPosition
Break at a particular position under a particular source.
Not available under no_position.
Fields

source: Option<ImmutableString>Source (empty if not available) of the break-point.
AtFunctionName
Break at a particular function call.
AtFunctionCall
Break at a particular function call with a particular number of arguments.
Fields

name: ImmutableStringFunction name.
AtProperty
Break at a particular property .
Not available under no_object.
Implementations
Sourceimpl BreakPoint
impl BreakPoint
Sourcepub const fn is_enabled(&self) -> bool
pub const fn is_enabled(&self) -> bool
Is this BreakPoint enabled?
Sourcepub fn enable(&mut self, value: bool)
pub fn enable(&mut self, value: bool)
Enable/disable this BreakPoint.